@@ -46,6 +46,9 @@
     #include <QtGui/QX11Info>
     #include <X11/Xlib.h>
     #include <X11/Xatom.h>
+    #include <QtDBus/QDBusConnection>
+    #include <mce/dbus-names.h>
+    #include <mce/mode-names.h>
 #endif
 
 MainWindow::MainWindow() :
@@ -114,6 +117,11 @@ void MainWindow::initialize()
     Core::map()->setTracking(true);
 
     grabZoomKeys(true);
+
+#ifdef Q_WS_MAEMO_5
+    QDBusConnection bus = QDBusConnection::systemBus();
+    bus.connect(MCE_SERVICE, MCE_SIGNAL_PATH, MCE_SIGNAL_IF, MCE_INACTIVITY_SIG , this, SLOT(setInactive(bool)));
+#endif
 }
 
 MainWindow::~MainWindow(){
@@ -130,7 +138,7 @@ void MainWindow::closeEvent(QCloseEvent *event) {
 }
 
 void MainWindow::positionUpdated(const QGeoPositionInfo &info) {
-    //qDebug() << "GPS Position updated:" << QDateTime::currentDateTime().toString();
+    qDebug() << "GPS Position updated:" << QDateTime::currentDateTime().toString();
     Core::map()->positionUpdated(info);
     statusBarGPS->setText("");
 
@@ -381,3 +389,14 @@ void MainWindow::mapPanned()
     disconnect(Core::map(), SIGNAL(resized()), this, SLOT(mapResized()));
     disconnect(Core::map(), SIGNAL(panned()), this, SLOT(mapPanned()));
 }
+
+void MainWindow::setInactive(bool inactive)
+{
+    if(inactive) {
+        qDebug() << "Application now inactive";
+        m_gps->stopUpdates();
+    } else {
+        qDebug() << "Application now active";
+        m_gps->startUpdates();
+    }
+}
