@@ -30,6 +30,7 @@
 #include <QtGui/QVBoxLayout>
 
 #include <QtLocation/QGeoBoundingBox>
+#include <QtLocation/QGeoMapPolygonObject>
 
 /**
  * Private class ensures that map always fills view.
@@ -135,7 +136,35 @@ void MobilityMap::initialize()
     m_positionMarker->setZValue(1);
     map->addMapObject(m_positionMarker);
 
+    setRegion();
+
     rowsInserted(QModelIndex(), 0, m_model->rowCount() - 1);
+
+}
+
+void MobilityMap::setRegion()
+{
+    QGeoMapPolygonObject *region = new QGeoMapPolygonObject();
+    QColor color(Qt::blue);
+    color.setAlpha(30);
+    QBrush brush(color);
+    region->setBrush(brush);
+
+    QPen pen(Qt::blue);
+    pen.setWidth(5);
+    region->setPen(pen);
+    region->setPen(pen);
+
+    QList<QGeoCoordinate> path;
+    path.append(QGeoCoordinate(48.426698, 9.904337));
+    path.append(QGeoCoordinate(48.36949, 9.948518));
+    path.append(QGeoCoordinate(48.364419, 10.010472));
+    path.append(QGeoCoordinate(48.393634, 10.028695));
+    path.append(QGeoCoordinate(48.417814, 10.0047));
+    path.append(QGeoCoordinate(48.41738, 9.96521));
+    region->setPath(path);
+    region->setZValue(0);
+    m_map->addMapObject(region);
 }
 
 void MobilityMap::positionUpdated(const QGeoPositionInfo &info)
